Learn R Programming

GCEstim (version 0.1.0)

ER.test: Entropy Ratio test

Description

The Entropy Ratio test - which corresponds to the likelihood ratio, or empirical ratio, test - measures the entropy discrepancy between the constrained and the unconstrained models.

Usage

ER.test(object)

Value

A matrix with the X-squared statistics, degrees of freedom and p-value for each parameter.

Arguments

object

fitted lmgce object.

Author

Jorge Cabral, jorgecabral@ua.pt

Examples

Run this code
# \donttest{
res_gce_package <-
  lmgce(y ~ .,
        data = dataGCE,
        boot.B = 50,
        seed = 230676)
# }

ER.test(res_gce_package)

Run the code above in your browser using DataLab