Learn R Programming

GCEstim (version 0.1.0)

changestep: Change the step from lmgce object

Description

Changes the number of GCE reestimations of a lmgce object

Usage

changestep(object, twosteps.n, verbose = 0)

Value

An lmgce object with the specified number of GCE reestimations

Arguments

object

fitted lmgce object.

twosteps.n

An integer that defines the number of GCE reestimations to be used.

verbose

An integer to control how verbose the output is. For a value of 0 no messages or output are shown and for a value of 3 all messages are shown. The default is verbose = 0.

Author

Jorge Cabral, jorgecabral@ua.pt

Examples

Run this code
# \donttest{
res_gce_package <-
  lmgce(y ~ .,
        data = dataGCE,
        twosteps.n = 10,
        seed = 230676)

res_gce_package_change_step <- changestep(res_gce_package, 5)

summary(res_gce_package)

summary(res_gce_package_change_step)
# }

Run the code above in your browser using DataLab