Learn R Programming

GCEstim (version 0.1.0)

coefficients.tsbootgce: Extract tsbootgce Model Coefficients

Description

Extract coefficients from a tsbootgce object

Usage

# S3 method for tsbootgce
coefficients(object, which = NULL, seed = object$seed, ...)

Value

Returns the coefficients from a tsbootgce object

Arguments

object

Fitted tsbootgce model object.

which

The default is which = NULL and returns the coefficients defined in the argument coef.method from the tsbootgce object. Can be set as "mode" or "median" and the mode and median coefficients will be computed, respectively (see hdr).

seed

A single value, interpreted as an integer, for reproducibility or NULL for randomness. The default is seed = object$seed.

...

Additional arguments.

Author

Jorge Cabral, jorgecabral@ua.pt

Examples

Run this code
# \donttest{
res.tsbootgce <-
  tsbootgce(
    formula = CO2 ~ 1 + L(GDP, 1) + L(EPC, 1) + L(EU, 1),
    data = moz_ts)

coefficients(res.tsbootgce)
# }

Run the code above in your browser using DataLab