Learn R Programming

GCEstim (version 0.1.0)

fitted.values.lmgce: Calculate lmgce Fitted Values

Description

The fitted values for the linear model represented by a lmgce object are extracted.

Usage

# S3 method for lmgce
fitted.values(object, ...)

Value

Returns a vector with the fitted values for the linear model represented by a lmgce object.

Arguments

object

Fitted lmgce model object.

...

additional arguments.

Author

Jorge Cabral, jorgecabral@ua.pt

Examples

Run this code
# \donttest{
res_gce_package <-
  lmgce(y ~ .,
        data = dataGCE,
        boot.B = 50,
        seed = 230676)
# }
fitted.values(res_gce_package)

Run the code above in your browser using DataLab