Learn R Programming

GCEstim (version 0.1.0)

lmgceAddin: An add-in to easily generate the code for a lmgce analysis

Description

Select data and choose the arguments to be used. The execution of the code is also possible within the addin.

Usage

lmgceAddin()

Arguments

Value

The code to be use in the lmgce analysis.

Details

An addin for lmgce

Examples

Run this code
# \donttest{
lmgceAddin()
# }

Run the code above in your browser using DataLab