Learn R Programming

GCEstim (version 0.1.0)

model.matrix.lmgce: Extract design matrix from lmgce object

Description

Returns the design matrix used to fit lmgce object.

Usage

# S3 method for lmgce
model.matrix(object, ...)

Value

A numeric matrix with one row for each observation and one column for each parameter in the model.

Arguments

object

fitted lmgce object.

...

additional arguments.

Author

Jorge Cabral, jorgecabral@ua.pt

Examples

Run this code
# \donttest{
res_gce_package <-
  lmgce(y ~ .,
        x = TRUE,
        data = dataGCE,
        boot.B = 50,
        seed = 230676)

model.matrix(res_gce_package)
# }

Run the code above in your browser using DataLab