Learn R Programming

GCEstim (version 0.1.0)

nobs.lmgce: Extract the Number of Observations from a lmgce model fit

Description

Extract the number of ‘observations’ from a lmgce model fit.

Usage

# S3 method for lmgce
nobs(object, ...)

Value

An integer scalar representing the number of observations (rows) used in fitting the lmgce model object.

Arguments

object

Fitted lmgce model object.

...

additional arguments.

Author

Jorge Cabral, jorgecabral@ua.pt

Examples

Run this code
# \donttest{
res_gce_package <-
  lmgce(y ~ .,
        data = dataGCE,
        boot.B = 50,
        seed = 230676)
# }

nobs(res_gce_package)

Run the code above in your browser using DataLab