powered by
lmgce
Predicted values based on a fitted model lmgce object.
# S3 method for lmgce predict( object, newdata, interval = c("none", "confidence"), type = c("response", "terms"), level = 0.95, terms = NULL, na.action = na.pass, ... )
predict.lmgce produces a vector of predictions.
predict.lmgce
Fitted lmgce model object.
An optional data frame in which to look for variables with which to predict. If omitted, the fitted values are used.
One of c("none", "confidence"). Type of interval calculation. Can be abbreviated.
c("none", "confidence")
One of c("response", "terms"). Type of prediction (response or model term). Can be abbreviated.
c("response", "terms")
Tolerance/confidence level (0,1).
if type = "terms", which terms (default is all terms), a character vector.
type = "terms"
character
function determining what should be done with missing values in newdata. The default is to predict NA.
newdata
NA
additional arguments.
Jorge Cabral, jorgecabral@ua.pt
# \donttest{ res_gce_package <- lmgce(y ~ ., data = dataGCE, boot.B = 50, seed = 230676) # } predict(res_gce_package, dataGCE.test)
Run the code above in your browser using DataLab