Learn R Programming

GCEstim (version 0.1.0)

print.summary.lmgce: Print Summary of lmgce Model Fits

Description

print.summary method for class lmgce.

Usage

# S3 method for summary.lmgce
print(
  x,
  digits = max(3L, getOption("digits") - 3L),
  symbolic.cor = x$symbolic.cor,
  signif.stars = getOption("show.signif.stars"),
  ...
)

Value

The function print.summary.lmgce prints the information in a summary.lmgce object.

Arguments

x

an object of class summary.lmgce, usually, a result of a call to summary.lmgce.

digits

The number of significant digits to use when printing.

symbolic.cor

Boolean value. if TRUE, print the correlations in a symbolic form (see symnum) rather than as numbers.

signif.stars

Boolean value. if TRUE, ‘significance stars’ are printed for each coefficient.

...

Further arguments passed to or from other methods.

Author

Jorge Cabral, jorgecabral@ua.pt

Examples

Run this code
# \donttest{
res_gce_package <-
  lmgce(y ~ .,
        data = dataGCE,
        boot.B = 50,
        seed = 230676)
# }

summary(res_gce_package)

summary(res_gce_package, ci.level = 0.90, ci.method = "basic")

Run the code above in your browser using DataLab