powered by
lmgce
residuals is a function which extracts model residuals from lmgce objects. The abbreviated form resid is an alias for residuals.
residuals
resid
# S3 method for lmgce residuals(object, ...)
Returns the residuals from a lmgce object
Fitted lmgce model object.
additional arguments.
Jorge Cabral, jorgecabral@ua.pt
# \donttest{ res_gce_package <- lmgce(y ~ ., data = dataGCE, boot.B = 50, seed = 230676) # } residuals(res_gce_package)
Run the code above in your browser using DataLab