summary method for class lmgce. Function used to produce
summary information from a fitted linear regression model via generalized
cross entropy as represented by object of class lmgce.
# S3 method for lmgce
summary(
object,
call = TRUE,
correlation = FALSE,
symbolic.cor = FALSE,
ci.level = NULL,
ci.method = c("z", "percentile", "basic"),
boot.B = ifelse(object$boot.B == 0, 100, object$boot.B),
boot.method = object$boot.method,
...
)The function summary.lmgce computes and returns a list of
summary statistics of the fitted lmgce linear model given in
object, using the components (list elements) "call" and "terms" from
its argument, plus
the residuals, that is response minus fitted values.
a \(p \times 4\) matrix, where \(p\) is the number of non-aliased coefficients, with columns for the estimated coefficient, its standard error, z-statistic and corresponding (two-sided) p-value. Aliased coefficients are omitted.
a \(p \times 3\) matrix with columns for the normalized entropy (NormEnt), and lower (LL) and upper (UL) limits for each of the \(K+1\) support spaces.
named logical vector showing if the original coefficients are aliased.
the square root of the estimated variance of the random error.
degrees of freedom, a 3-vector \((p, n - p)\) the first being the number of non-aliased coefficients, the last being the \(p\) minus the number of included individuals \(n\).
\(R^2\), the ‘fraction of variance explained by the model’
the above \(R^2\) statistic ‘adjusted’, penalizing for higher \(p\).
a \(p \times p\) matrix of covariances of the \(\hat \beta\)
when applicable, the upper limit of the standardized
support chosen, when support.method = "standardized" or the factor used
when support.method = "ridge".
method chosen for the support's limits
the normalized entropy of the model.
the cross-validation normalized entropy of the model.
the standard deviation of the cross-validation normalized entropy of the model.
the error measure chosen
which criterion/standardized/factor support was used
the value of the error measure
the cross-validation value of the error measure
the standard deviation of the cross-validation value of the error measure
the correlation matrix corresponding to the above
cov.unscaled, if correlation = TRUE is specified.
(only if correlation = TRUE) The value of the
argument symbolic.cor.
from object, if present there.
Fitted lmgce model object.
Boolean value. if TRUE, the call used is returned.
The default is model = TRUE.
Boolean value. if TRUE, the correlation
matrix of the estimated parameters is returned and printed.
Boolean value. if TRUE, print the correlations in
a symbolic form (see symnum) rather than as numbers.
the confidence level (0,1) required to compute the confidence
interval. The default is ci.level = NULL which results in the omission
of the confidence interval.
method used to compute a confidence interval. One of
c("z","percentile", "basic"). The default is ci.method = "z".
A single positive integer greater or equal to 10 for the number
of bootstrap replicates for the computation of the bootstrap confidence
interval(s), to be used when method = c("percentile", "basic") and
when object was created with boot.B = 0. The default is
boot.B = 100 when the object has no previous sampling information
and boot.B = object$boot.B otherwise, which corresponds to
the boot.B given to lmgce when the object was created.
Method used for bootstrapping. One of
c("residuals", "cases", "wild") which corresponds to resampling on
residuals, on individual cases or on residuals multiplied by a N(0,1) variable,
respectively. The default is boot.method = object$boot.method.
additional arguments.
Jorge Cabral, jorgecabral@ua.pt
# \donttest{
res_gce_package <-
lmgce(y ~ .,
data = dataGCE,
boot.B = 50,
seed = 230676)
# }
sm_res_gce_package <- summary(res_gce_package)
str(sm_res_gce_package)
sm_res_gce_package$coefficients
Run the code above in your browser using DataLab