Learn R Programming

GCEstim (version 0.1.0)

vcov.lmgce: Extract lmgce Model's Variance-Covariance Matrix

Description

Returns the variance-covariance matrix of the main parameters of a lmgce object

Usage

# S3 method for lmgce
vcov(object, ...)

Value

A matrix of the estimated covariances between the parameter estimates in the linear predictor of the lmgce model.

Arguments

object

Fitted lmgce model object.

...

additional arguments.

Author

Jorge Cabral, jorgecabral@ua.pt

Examples

Run this code
# \donttest{
res_gce_package <-
  lmgce(y ~ .,
        data = dataGCE,
        boot.B = 50,
        seed = 230676)
# }
vcov(res_gce_package)

Run the code above in your browser using DataLab