powered by
lmgce
Select data and choose the arguments to be used. The execution of the code is also possible within the addin.
lmgceAddin()
The code to be use in the lmgce analysis.
An addin for lmgce
# \donttest{ lmgceAddin() # }
Run the code above in your browser using DataLab