powered by
lmgce
Returns the design matrix used to fit lmgce object.
# S3 method for lmgce model.matrix(object, ...)
A numeric matrix with one row for each observation and one column for each parameter in the model.
fitted lmgce object.
additional arguments.
Jorge Cabral, jorgecabral@ua.pt
# \donttest{ res_gce_package <- lmgce(y ~ ., x = TRUE, data = dataGCE, boot.B = 50, seed = 230676) model.matrix(res_gce_package) # }
Run the code above in your browser using DataLab