powered by
lmgce
Returns the variance-covariance matrix of the main parameters of a lmgce object
# S3 method for lmgce vcov(object, ...)
A matrix of the estimated covariances between the parameter estimates in the linear predictor of the lmgce model.
Fitted lmgce model object.
additional arguments.
Jorge Cabral, jorgecabral@ua.pt
# \donttest{ res_gce_package <- lmgce(y ~ ., data = dataGCE, boot.B = 50, seed = 230676) # } vcov(res_gce_package)
Run the code above in your browser using DataLab